@@ -197,7 +197,7 @@ class Seti():
 
     # Recharger
 
-    def create_recharger(self, value: int, secret: str):
+    def create_recharger(self, value: int,  secret: str):
         self.is_error = False
         self.validate_value(value)
         data_create_recharger = {
@@ -289,3 +289,10 @@ class Seti():
         CREATE_USER_URL = "validate-user"
         encode_data = self.sign_data(data_read_cash)
         return ResponseValidateUsersExist(self.send_request(data_read_cash, encode_data, CREATE_USER_URL))
+
+    def create_associated_wallet(self, iso_code: str):
+        self.is_error = False
+        create_wallet = {"isoCode": iso_code}
+        CREATE_ASSOCIATED_WALLET = "create-associated-wallet"
+        encode_data = self.sign_data(create_wallet)
+        return ResponseCreateWallet(self.send_request(create_wallet, encode_data, CREATE_ASSOCIATED_WALLET))
